/*
* Licensed Materials - Property of IBM
* 5725-G92 (C) Copyright IBM Corp. 2006, 2013. All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or
* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
*/

function wlCommonInit(){
	
	if (WL.Client.getEnvironment() === 'iphone' ||
			WL.Client.getEnvironment() === 'ipad' ||
			WL.Client.getEnvironment() === 'android') {
			
			//gets created when we initialize the collection.
			var usersCollection = null,
				nameTag = WLJQ('input#name'),
				ageTag = WLJQ('input#age'),
				statusTag = WLJQ('div#status'),
				passwordTag = WLJQ('input#password'),
				fipsStatusTag = WLJQ('div#fipsStatus'),
				tableTag = WLJQ('table#user_table'),
				fipsEnabled = false,
				
				logMessage = function (msg) {
					WL.Logger.debug(msg);
					statusTag.text(msg);
					tableTag.html('');
				},
				
				//Generic callback called when there's a failure
				genericFailureCallback = function  (err) {
					logMessage(err + ' Error Message: ' + WL.JSONStore.getErrorMessage(err));
				},
				
				//Simple function that check if collection is init
				checkColInit = function (obj) {
					if ((typeof obj === 'undefined') || obj === null){
						logMessage('You must initialize the collection first.');
						return false;
					}else{ return true; }
				};
				
				// Initializes the collection
				WLJQ('button#initCollection').bind('click', function () {

					var collectionName = 'users';
					var searchFields = {name: 'string', age: 'number'};
					var pwd = passwordTag.val();

					if(pwd.length <= 0 && fipsEnabled == true){
						logMessage("You must have a password set in order to initialze in FIPS mode.");
						return;
					}
					
					if (pwd.length > 0) {
						WL.Logger.debug('Using Password with length: ' + pwd.length);
						WL.JSONStore.usePassword(pwd);
						passwordTag.val('');
						pwd = null;
					}
					
					var successCallback =   function (data) {
						console.log("Collection has been successfully initialized.");
						statusTag.text("");
						logMessage("Collection has been successfully initialized.");
					};

					console.log("FIPS ENABLED: " + fipsEnabled);
					var options = {onSuccess: successCallback, onFailure: genericFailureCallback, fipsEnabled: fipsEnabled};

					usersCollection = WL.JSONStore.initCollection(collectionName, searchFields, options);
				});

				// Adds a new record to the datastore
				WLJQ('button#add').bind('click', function () {
					WL.Logger.debug('Called button#add');
					if (!checkColInit(usersCollection)) {return;}

					var name = nameTag.val(),
					age = ageTag.val();

					var successCallback =   function (data) {
						logMessage('Added ' + data + ' document.');
						//Clear Text Boxes
						nameTag.val('');
						ageTag.val('');
					};

					var options = {onSuccess: successCallback, onFailure: genericFailureCallback};
					usersCollection.store({name: name, age: age}, options);

				});

				//Does a findAll on the 'users' collection
				WLJQ('button#find').bind('click', function () {

					WL.Logger.debug('Called button#find');
					if (!checkColInit(usersCollection)) {return;}

					usersCollection.findAll({onFailure: genericFailureCallback, onSuccess: function (results) {
						reloadTable(results);
					}});

				});
				
				//Does a findAll on the 'users' collection
				WLJQ('button#fipsToggle').bind('click', function () {
					WL.Logger.debug('Called button#fipsToggle');
					fipsEnabled = !fipsEnabled;
					
					if(fipsEnabled == true){
						fipsStatusTag.text("FIPS mode has now been requested. If the FIPS libraries are installed in the project, JSONStore will run in FIPS mode.");
						WLJQ("#fipsToggle").text('Disable FIPS Mode');
					}else{
						fipsStatusTag.text("FIPS Mode is now disabled.");
						WLJQ("#fipsToggle").text('Request FIPS Mode');
					}
					
				});

				//Convenience function to load the table with entries
				var reloadTable = function(results) {

					var msg = '<tr><td>ID</td><td>NAME</td><td>AGE</td></tr>',
					i = results.length,
					curr;

					if ( i < 1) {
						logMessage('No Entries Found');
					} else {

						while ( i-- ) {
							curr = results[i].json;
							id = results[i]._id;
							msg += '<tr><td>' + id + '</td><td>' + curr.name + '</td><td>' + curr.age + '</td></tr>';
						}

						WL.Logger.debug('Find Raw Results: ' + JSON.stringify(results));
						logMessage(''); //Clear Log
						tableTag.html(msg); //Add Table
					}

				};
	}

}


